@@ -22,12 +22,8 @@ void IntroItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 
     painter->save();
 
-    painter->setBrush(Qt::black);
-    painter->setPen(Qt::NoPen);
-    painter->drawRect(boundingRect());
-
     painter->setBrush(Qt::NoBrush);
-    painter->setPen(Qt::white);
+    painter->setPen(Qt::black);
 
     // Get font metrics
     QFontMetricsF fontMetricsF(painter->font());
